---
name: Usage support
about: For questions related to how to use MUSE
title: "[QUESTION]"
labels: question
assignees: ''

---

## What you want to achieve

(Please, describe in detail what you want to achieve and what parts of the documentation you have checked to do so)

## What you have tried

(If you have already taken some steps, please, describe here what you have tried. Provide any input files you are trying to use).

## Context

Please, complete the following to better understand the system you are using to run MUSE.

- Operating system (eg. Windows 10):
- MUSE version (eg. 1.0.1):
- Installation method (eg. pipx, pip, development mode):
- Python version (you can get this running `python --version`):
